@@ -1,7 +1,9 @@
 package Template::Liquid::Block;
-our $VERSION = '1.0.11';
+our $VERSION = '1.0.12';
 require Template::Liquid::Error;
 use base 'Template::Liquid::Document';
+use strict;
+use warnings;
 
 sub new {
     my ($class, $args) = @_;
